aboutsummaryrefslogtreecommitdiff
path: root/include/clang/Lex/TokenLexer.h
diff options
context:
space:
mode:
authorChandler Carruth <chandlerc@gmail.com>2011-07-14 08:20:34 +0000
committerChandler Carruth <chandlerc@gmail.com>2011-07-14 08:20:34 +0000
commitd0f5e443ceed37e1a72015bd109db8e5fc6206cf (patch)
tree4751311edcafa3f007b0bf7191d24f73394e6087 /include/clang/Lex/TokenLexer.h
parent7e7736aa826b4f8b29e1eae6584393f97243ab5a (diff)
Switch the TokenLexer's terminology from various forms of 'instantiate'
to 'expand' for macros. Only comments and uses local to the TokenLexer are updated. No functionality changed. git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@135137 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/clang/Lex/TokenLexer.h')
-rw-r--r--include/clang/Lex/TokenLexer.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/clang/Lex/TokenLexer.h b/include/clang/Lex/TokenLexer.h
index ea36e0e0e8..45ff8a0344 100644
--- a/include/clang/Lex/TokenLexer.h
+++ b/include/clang/Lex/TokenLexer.h
@@ -59,15 +59,15 @@ class TokenLexer {
///
unsigned CurToken;
- /// InstantiateLocStart/End - The source location range where this macro was
- /// instantiated.
- SourceLocation InstantiateLocStart, InstantiateLocEnd;
+ /// ExpandLocStart/End - The source location range where this macro was
+ /// expanded.
+ SourceLocation ExpandLocStart, ExpandLocEnd;
/// \brief Source location pointing at the source location entry chunk that
- /// was reserved for the current macro instantiation.
+ /// was reserved for the current macro expansion.
SourceLocation MacroExpansionStart;
- /// \brief The offset of the macro instantiation in the
+ /// \brief The offset of the macro expansion in the
/// "source location address space".
unsigned MacroStartSLocOffset;
@@ -162,7 +162,7 @@ private:
/// HandleMicrosoftCommentPaste - In microsoft compatibility mode, /##/ pastes
/// together to form a comment that comments out everything in the current
/// macro, other active macros, and anything left on the current physical
- /// source line of the instantiated buffer. Handle this by returning the
+ /// source line of the expanded buffer. Handle this by returning the
/// first token on the next line.
void HandleMicrosoftCommentPaste(Token &Tok);